	//
	//  littleNotesAppDelegate.m
	//  littleNotes
	//
	//  Created by Michael on 23.05.10.
	//  Copyright 2010 MOApp. All rights reserved.
	//

#import "littleNotesAppDelegate.h"

@implementation littleNotesAppDelegate

@synthesize window, data, dataPath;



#pragma mark -
#pragma mark Init/Dealloc


-(void)awakeFromNib
{
	[window center];	
	
	if (![[NSUserDefaults standardUserDefaults]boolForKey:@"firstStart"]) {
		[[NSUserDefaults standardUserDefaults]setInteger:2 forKey:@"notesSize"];
		[[NSUserDefaults standardUserDefaults]setInteger:3 forKey:@"notesFont"];
		[[NSUserDefaults standardUserDefaults]setBool:YES forKey:@"firstStart"];
	}
	
	[self applyFont];
	[self loadDataFromDisk];	
}


#pragma mark -
#pragma mark Data

-(void)loadDataFromDisk
{
	NSFileManager *fileManager = [NSFileManager defaultManager];	
	NSString *folder = @"~/Library/Application Support/littleNotes/";
	folder = [folder stringByExpandingTildeInPath];	
	if ([fileManager fileExistsAtPath: folder] == NO)
	{
		[fileManager createDirectoryAtPath: folder withIntermediateDirectories:YES attributes: nil error:NULL];
	}	
	NSString *path = nil;
	path = [NSHomeDirectory() stringByAppendingPathComponent: @"/Library/Application Support/littleNotes/Notes.plist"];
	
	self.dataPath = path;
	NSError *error = nil;
	if ([fileManager fileExistsAtPath:dataPath] == NO)
	{
		NSString *pathToDefaultPlist = [[NSBundle mainBundle] pathForResource:@"Notes" ofType:@"plist"];
		if ([fileManager copyItemAtPath:pathToDefaultPlist toPath:dataPath error:&error] == NO)
		{
			NSAssert1(0, @"Failed to copy data with error message '%@'.", [error localizedDescription]);
		}
	}
	self.data = [[[NSMutableArray alloc] initWithContentsOfFile:dataPath] autorelease];	
	
	[arrayController setSelectionIndex:[[NSUserDefaults standardUserDefaults]integerForKey:@"selectionIndex"]];
}

-(void)saveDataToDisk
{
	[data writeToFile:dataPath atomically:NO];
}



#pragma mark -
#pragma mark Delegate Notifications


- (void)applicationDidFinishLaunching:(NSNotification *)aNotification {
	
}

- (void)applicationWillTerminate:(NSNotification *)aNotification {
	
	[self saveDataToDisk];
	[[NSUserDefaults standardUserDefaults]setInteger:[arrayController selectionIndex] forKey:@"selectionIndex"];
}





#pragma mark -
#pragma mark Add/Delete


-(IBAction)addNote:(id)sender
{
	NSString *title = [NSString stringWithFormat:@"%@",[titleField stringValue]];
	NSString *syncID = [NSString stringWithFormat:@"%d", time(NULL)];	
	NSMutableDictionary *newItem = [[NSMutableDictionary alloc] initWithObjectsAndKeys:
									syncID, @"syncID",
									[NSDate date], @"syncDate",
									[NSNumber numberWithBool:NO], @"isDirty",
									title, @"title",
									@"", @"body",
									@"", @"tags",
									@"", @"misc1",
									@"", @"misc2",
									@"", @"misc3",
									@"", @"misc4",
									@"", @"misc5",
									nil, nil];	
	
	if (newItem) {
		[arrayController addObject:newItem];
		[arrayController rearrangeObjects];
	}
	
	 [NSApp endSheet:newSheet];

}

-(IBAction)deleteNote:(id)sender
{
	NSAlert* deleteAlert = [NSAlert alertWithMessageText:NSLocalizedString(@"Delete note", @"") 
										   defaultButton:NSLocalizedString(@"Delete", @"")
										 alternateButton:NSLocalizedString(@"Cancel", @"")
											 otherButton: nil
							   informativeTextWithFormat: NSLocalizedString(@"Deleting notes is permanent and cannot be undone. Do you really want to delete the selected note?", @"Delete Alert Sheet Text"), nil];
	
	[deleteAlert beginSheetModalForWindow:nil 
							modalDelegate:self 
						   didEndSelector:@selector(deleteWarningSheetDidEnd:returnCode:contextInfo:) 
							  contextInfo:nil];
}

- (void)deleteWarningSheetDidEnd:(NSWindow *)sheet returnCode:(int)returnCode contextInfo:(void *)contextInfo;
{
	if(1 == returnCode)
	{			
		[arrayController removeObjectAtArrangedObjectIndex:[arrayController selectionIndex]];		
	}
}




#pragma mark -
#pragma mark Preferences


-(IBAction)showPrefs:(id)sender
{
	[prefs center];
	[prefs makeKeyAndOrderFront:self];
}




-(void)applyFont
{
	int size;
	int tag1 = [[NSUserDefaults standardUserDefaults] integerForKey: @"notesSize"];			
	switch (tag1)
	{
		case 0:
			size = 11;
			break;			
		case 1:
			size = 12;
			break;
			
		case 2:
			size = 13;
			break;
		case 3:
			size = 14;
			break;
		case 4:
			size = 15;
			break;
		case 5:
			size = 16;
			break;
		case 6:
			size = 17;
			break;
		case 7:
			size = 18;
			break;
		case 8:
			size = 19;
			break;
			
		default:
			size = 13;
			break;				
	}	
	
	
	NSString *selectedFont;		
	int tag001 = [[NSUserDefaults standardUserDefaults] integerForKey: @"notesFont"];
	switch (tag001)
	{
			selectedFont = @"American Typewriter";
			break;			
		case 1:
			selectedFont = @"Arial";
			break;			
		case 2:
			selectedFont = @"Courier";
			break;
		case 3:
			selectedFont = @"Georgia";
			break;
		case 4:
			selectedFont = @"Helvetica";
			break;
		case 5:
			selectedFont = @"Times";
			break;
		case 6:
			selectedFont = @"Verdana";
			break;	
		default:
			selectedFont = @"Georgia";
			break;			
	}
	
	
	NSColor *color = [NSColor blackColor];
	NSFont *font;
	font = [NSFont fontWithName:selectedFont size:size];
	
	NSMutableParagraphStyle *paragraph = [[NSMutableParagraphStyle alloc] init];
	[paragraph setLineSpacing:1.2];	
	
	[textView setTypingAttributes:[NSDictionary dictionaryWithObjectsAndKeys:font, NSFontAttributeName, color, NSForegroundColorAttributeName,  paragraph,    NSParagraphStyleAttributeName, nil]];
	
	[[textView textStorage] setAttributes:[NSDictionary dictionaryWithObjectsAndKeys:font, NSFontAttributeName, color, NSForegroundColorAttributeName,  paragraph,    NSParagraphStyleAttributeName, nil] range:NSMakeRange(0,[[[textView textStorage]string]length])];
	
	
}

-(IBAction)setFont:(id)sender
{
	[self applyFont];
}



#pragma mark -
#pragma mark Sheets


- (void)didEndSheet:(NSWindow*)theSheet returnCode:(int)returnCode contextInfo:(void*)contextInfo
{
    [theSheet orderOut:self];
}

- (IBAction)closeSheet:(id)sender
{
    [NSApp endSheet:newSheet];
}

- (IBAction)openSheet:(id)sender
{
	[titleField setStringValue:@"New Note"];
	[NSApp		beginSheet:newSheet modalForWindow:window
		 modalDelegate:self didEndSelector:@selector(didEndSheet:returnCode:contextInfo:) contextInfo:nil];
	[titleField selectText:self];
}





@end
